summaryrefslogtreecommitdiffstats
path: root/src/mame/drivers/atarisy1.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/drivers/atarisy1.cpp')
-rw-r--r--src/mame/drivers/atarisy1.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/mame/drivers/atarisy1.cpp b/src/mame/drivers/atarisy1.cpp
index 511b1517cef..ee40670efd1 100644
--- a/src/mame/drivers/atarisy1.cpp
+++ b/src/mame/drivers/atarisy1.cpp
@@ -2499,10 +2499,14 @@ void atarisy1_state::init_slapstic()
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); });
// The slapstic seems to trigger on the whole rom, but that slows things down too much. limit to the range marble madness actually needs
m_maincpu->space(AS_PROGRAM).install_readwrite_tap(0x2ff5a, 0x2ff5b, 0, "slapstic",
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); });
+ m_maincpu->space(AS_PROGRAM).install_readwrite_tap(0x101d4, 0x101d9, 0, "slapstic",
+ [this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },
+ [this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); });
}
void atarisy1_state::init_marble()
@@ -2499,10 +2499,14 @@ void atarisy1_state::init_slapstic()
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); });
- // The slapstic seems to trigger on the whole rom, but that slows things down too much. limit to the range marble madness actually needs
+ // Some states of the slapstic seems trigger on the whole address space, but that slows things down too much and this point.
+ // limit to the ranges marble madness and peterpak actually need
m_maincpu->space(AS_PROGRAM).install_readwrite_tap(0x2ff5a, 0x2ff5b, 0, "slapstic",
[this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },